==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicBorders__24MarginBorder.h <==
// public class javax.swing.plaf.basic.BasicBorders$MarginBorder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 7cc7ea099ad26396 javax_swing_plaf_basic_BasicBorders__24MarginBorder

// header file dependencies
// @dep_header javax_swing_border_AbstractBorder

#include "javax/swing/border/AbstractBorder.h"

#ifndef _JC_javax_swing_plaf_basic_BasicBorders__24MarginBorder_H_
#define _JC_javax_swing_plaf_basic_BasicBorders__24MarginBorder_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$refs	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object;

typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$fields_struct	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vmethods	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtable	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtype	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$fields_struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object *);

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object *, struct _jc_java_awt_Component$object *);
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$method$getBorderInsets$8c7185b35170132d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$method_info$getBorderInsets$8c7185b35170132d;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object *, struct _jc_java_awt_Component$object *);
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$8c7185b35170132d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vmethods	javax_swing_plaf_basic_BasicBorders__24MarginBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$refs {
    _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$sub_refs	javax_swing_plaf_basic_BasicBorders__24MarginBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$sub_nonrefs	javax_swing_plaf_basic_BasicBorders__24MarginBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object {
	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtype _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicBorders__24MarginBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicBorders__24MarginBorder_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicBorders__24MarginBorder.h <==
// public class javax.swing.plaf.basic.BasicBorders$MarginBorder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 7cc7ea099ad26396 javax_swing_plaf_basic_BasicBorders__24MarginBorder

// header file dependencies
// @dep_header javax_swing_border_AbstractBorder

#include "javax/swing/border/AbstractBorder.h"

#ifndef _JC_javax_swing_plaf_basic_BasicBorders__24MarginBorder_H_
#define _JC_javax_swing_plaf_basic_BasicBorders__24MarginBorder_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$refs	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object;

typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$fields_struct	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vmethods	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtable	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtype	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$fields_struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$method$getBorderInsets$8c7185b35170132d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$method_info$getBorderInsets$8c7185b35170132d;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$8c7185b35170132d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vmethods	javax_swing_plaf_basic_BasicBorders__24MarginBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$refs {
    _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$sub_refs	javax_swing_plaf_basic_BasicBorders__24MarginBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$sub_nonrefs	javax_swing_plaf_basic_BasicBorders__24MarginBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object {
	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$vtype _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicBorders__24MarginBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicBorders__24MarginBorder_H_ */
